ref: f7cd6e7aad3f8d4589ee91895c4870d2f2d4a789
parent: 57f4548dafde69d65a5051de2e4218cbef969966
author: ruil2 <[email protected]>
date: Mon Aug 11 12:08:49 EDT 2014
use WelsEnc namespace instead of WelsSVCEnc
--- a/codec/console/enc/src/welsenc.cpp
+++ b/codec/console/enc/src/welsenc.cpp
@@ -84,7 +84,7 @@
#include <iostream>
using namespace std;
-using namespace WelsSVCEnc;
+using namespace WelsEnc;
/*
* Layer Context
--- a/codec/encoder/core/inc/au_set.h
+++ b/codec/encoder/core/inc/au_set.h
@@ -46,7 +46,7 @@
#include "parameter_sets.h"
#include "param_svc.h"
#include "utils.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
/*!
*************************************************************************************
* \brief to write Sequence Parameter Set (SPS)
--- a/codec/encoder/core/inc/bit_stream.h
+++ b/codec/encoder/core/inc/bit_stream.h
@@ -36,7 +36,7 @@
#include "typedefs.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
//#include "macros.h"
/*
--- a/codec/encoder/core/inc/deblocking.h
+++ b/codec/encoder/core/inc/deblocking.h
@@ -44,7 +44,7 @@
#include "encoder_context.h"
#include "wels_func_ptr_def.h"
#include "deblocking_common.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
//struct tagDeblockingFunc;
--- a/codec/encoder/core/inc/decode_mb_aux.h
+++ b/codec/encoder/core/inc/decode_mb_aux.h
@@ -37,7 +37,7 @@
#include "macros.h"
#include "wels_func_ptr_def.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
void WelsDequantLumaDc4x4 (int16_t* pRes, const int32_t kiQp);
void WelsIHadamard4x4Dc (int16_t* pRes);
--- a/codec/encoder/core/inc/dq_map.h
+++ b/codec/encoder/core/inc/dq_map.h
@@ -42,7 +42,7 @@
#if !defined(WELS_ENCODER_DEPENDENCY_QUAILITY_IDC_MAP_H__)
#define WELS_ENCODER_DEPENDENCY_QUAILITY_IDC_MAP_H__
-namespace WelsSVCEnc {
+namespace WelsEnc {
/*
* Dependency Quality IDC
*/
--- a/codec/encoder/core/inc/encode_mb_aux.h
+++ b/codec/encoder/core/inc/encode_mb_aux.h
@@ -37,7 +37,7 @@
#include "wels_func_ptr_def.h"
#include "copy_mb.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
void WelsInitEncodingFuncs (SWelsFuncPtrList* pFuncList, uint32_t uiCpuFlag);
int32_t WelsGetNoneZeroCount_c (int16_t* pLevel);
--- a/codec/encoder/core/inc/encoder.h
+++ b/codec/encoder/core/inc/encoder.h
@@ -42,7 +42,7 @@
#include "encoder_context.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
/*!
* \brief request specific memory for SVC
* \param pEncCtx sWelsEncCtx*
--- a/codec/encoder/core/inc/encoder_context.h
+++ b/codec/encoder/core/inc/encoder_context.h
@@ -58,7 +58,7 @@
#include "mt_defs.h" // for multiple threadin,
#include "WelsThreadLib.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
/*
* reference list for each quality layer in SVC
--- a/codec/encoder/core/inc/extern.h
+++ b/codec/encoder/core/inc/extern.h
@@ -43,7 +43,7 @@
#include "typedefs.h"
#include "encoder_context.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
/*!
* \brief initialize source picture body
--- a/codec/encoder/core/inc/get_intra_predictor.h
+++ b/codec/encoder/core/inc/get_intra_predictor.h
@@ -44,7 +44,7 @@
#include "typedefs.h"
#include "wels_func_ptr_def.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
void WelsI4x4LumaPredV_c (uint8_t* pPred, uint8_t* pRef, const int32_t kiStride);
void WelsI4x4LumaPredH_c (uint8_t* pPred, uint8_t* pRef, const int32_t kiStride);
void WelsI4x4LumaPredDc_c (uint8_t* pPred, uint8_t* pRef, const int32_t kiStride);
--- a/codec/encoder/core/inc/mb_cache.h
+++ b/codec/encoder/core/inc/mb_cache.h
@@ -39,7 +39,7 @@
#include "wels_const.h"
#include "macros.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
/*
* MB Cache information, such one cache should be defined within a slice
--- a/codec/encoder/core/inc/mc.h
+++ b/codec/encoder/core/inc/mc.h
@@ -44,7 +44,7 @@
/////////////////////luma MC//////////////////////////
//x y means dx(mv[0] & 3) and dy(mv[1] & 3)
-namespace WelsSVCEnc {
+namespace WelsEnc {
void WelsInitMcFuncs (SWelsFuncPtrList* pFuncList, uint32_t uiCpuFlag);
}
--- a/codec/encoder/core/inc/md.h
+++ b/codec/encoder/core/inc/md.h
@@ -45,7 +45,7 @@
#include "encode_mb_aux.h"
#include "wels_func_ptr_def.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
#define ME_REFINE_BUF_STRIDE 32
#define ME_REFINE_BUF_WIDTH_BLK4 8
#define ME_REFINE_BUF_WIDTH_BLK8 16
--- a/codec/encoder/core/inc/memory_align.h
+++ b/codec/encoder/core/inc/memory_align.h
@@ -39,7 +39,7 @@
#include <stdio.h>
#endif//MEMORY_CHECK
-namespace WelsSVCEnc {
+namespace WelsEnc {
class CMemoryAlign {
public:
--- a/codec/encoder/core/inc/mv_pred.h
+++ b/codec/encoder/core/inc/mv_pred.h
@@ -45,7 +45,7 @@
#include "svc_enc_macroblock.h"
#include "mb_cache.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
/*!
* \brief update pMv and uiRefIndex cache for current MB, only for P_16x16 (SKIP inclusive)
* \param
--- a/codec/encoder/core/inc/nal_encap.h
+++ b/codec/encoder/core/inc/nal_encap.h
@@ -45,7 +45,7 @@
#include "nal_prefix.h"
//SBitStringAux
-namespace WelsSVCEnc {
+namespace WelsEnc {
#define NAL_HEADER_SIZE (4)
/*
--- a/codec/encoder/core/inc/nal_prefix.h
+++ b/codec/encoder/core/inc/nal_prefix.h
@@ -38,7 +38,7 @@
#include "wels_common_basis.h"
#include "slice.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
///////////////////////////////////NAL Unit prefix/headers///////////////////////////////////
/* NAL Unix Header in AVC, refer to Page 56 in JVT X201wcm */
--- a/codec/encoder/core/inc/param_svc.h
+++ b/codec/encoder/core/inc/param_svc.h
@@ -51,7 +51,7 @@
#include "svc_enc_slice_segment.h"
#include "as264_common.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
#define INVALID_TEMPORAL_ID ((uint8_t)0xff)
@@ -513,6 +513,6 @@
return 0;
}
-}//end of namespace WelsSVCEnc
+}//end of namespace WelsEnc
#endif//WELS_ENCODER_PARAMETER_SVC_H__
--- a/codec/encoder/core/inc/parameter_sets.h
+++ b/codec/encoder/core/inc/parameter_sets.h
@@ -37,7 +37,7 @@
#include "wels_const.h"
#include "wels_common_basis.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
/* Sequence Parameter Set, refer to Page 57 in JVT X201wcm */
typedef struct TagWelsSPS {
--- a/codec/encoder/core/inc/picture.h
+++ b/codec/encoder/core/inc/picture.h
@@ -38,7 +38,7 @@
#include "as264_common.h"
#include "wels_common_basis.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
#define LIST_SIZE 0x10000 //(256*256)
typedef struct TagScreenBlockFeatureStorage {
//Input
@@ -112,7 +112,7 @@
// int32_t planes; // planes of YUV
//}Rs_Picture_t;
-} // end of namespace WelsSVCEnc {
+} // end of namespace WelsEnc {
#endif//WELS_PICTURE_H__
--- a/codec/encoder/core/inc/picture_handle.h
+++ b/codec/encoder/core/inc/picture_handle.h
@@ -43,7 +43,7 @@
#include "typedefs.h"
#include "memory_align.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
/*!
* \brief alloc picture pData with borders for each plane based width and height of picture
* \param kiWidth width of picture in pixels
--- a/codec/encoder/core/inc/property.h
+++ b/codec/encoder/core/inc/property.h
@@ -42,7 +42,7 @@
#include "typedefs.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
/*!
--- a/codec/encoder/core/inc/rc.h
+++ b/codec/encoder/core/inc/rc.h
@@ -48,7 +48,7 @@
#include "svc_enc_macroblock.h"
#include "slice.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
//trace
#define GOM_TRACE_FLAG 0
#define GOM_H_SCC 8
--- a/codec/encoder/core/inc/ref_list_mgr_svc.h
+++ b/codec/encoder/core/inc/ref_list_mgr_svc.h
@@ -46,7 +46,7 @@
#include "encoder_context.h"
#include "codec_app_def.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
typedef enum {
RECIEVE_UNKOWN = 0,
RECIEVE_SUCCESS = 1,
--- a/codec/encoder/core/inc/sample.h
+++ b/codec/encoder/core/inc/sample.h
@@ -36,7 +36,7 @@
#include "typedefs.h"
#include "wels_func_ptr_def.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
//======================SATD======================//
int32_t WelsSampleSatd16x16_c (uint8_t*, int32_t, uint8_t*, int32_t);
--- a/codec/encoder/core/inc/set_mb_syn_cavlc.h
+++ b/codec/encoder/core/inc/set_mb_syn_cavlc.h
@@ -45,7 +45,7 @@
#include "bit_stream.h"
#include "wels_func_ptr_def.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
--- a/codec/encoder/core/inc/slice.h
+++ b/codec/encoder/core/inc/slice.h
@@ -44,7 +44,7 @@
#include "bit_stream.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
/*******************************sub struct of slice header****************************/
--- a/codec/encoder/core/inc/slice_multi_threading.h
+++ b/codec/encoder/core/inc/slice_multi_threading.h
@@ -50,7 +50,7 @@
#include "svc_enc_slice_segment.h"
#include "WelsThreadLib.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
void UpdateMbListNeighborParallel (SSliceCtx* pSliceCtx,
SMB* pMbList,
const int32_t kiSliceIdc);
--- a/codec/encoder/core/inc/stat.h
+++ b/codec/encoder/core/inc/stat.h
@@ -40,7 +40,7 @@
#if !defined(WELS_ENCODER_STATISTICAL_DATA_H__)
#define WELS_ENCODER_STATISTICAL_DATA_H__
-namespace WelsSVCEnc {
+namespace WelsEnc {
/*
* Stat quality
--- a/codec/encoder/core/inc/svc_base_layer_md.h
+++ b/codec/encoder/core/inc/svc_base_layer_md.h
@@ -43,7 +43,7 @@
#include "md.h"
#include "mb_cache.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
void WelsMdIntraInit (sWelsEncCtx* pEncCtx, SMB* pCurMb, SMbCache* pMbCache, const int32_t kiSliceFirstMbXY);
int32_t WelsMdI16x16 (SWelsFuncPtrList* pFunc, SDqLayer* pCurDqLayer, SMbCache* pMbCache, int32_t iLambda);
int32_t WelsMdIntraChroma (SWelsFuncPtrList* pFunc, SDqLayer* pCurDqLayer, SMbCache* pMbCache, int32_t iLambda);
--- a/codec/encoder/core/inc/svc_enc_frame.h
+++ b/codec/encoder/core/inc/svc_enc_frame.h
@@ -46,7 +46,7 @@
#include "svc_enc_slice_segment.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
/*
* Frame level in SVC DQLayer instead.
--- a/codec/encoder/core/inc/svc_enc_golomb.h
+++ b/codec/encoder/core/inc/svc_enc_golomb.h
@@ -44,7 +44,7 @@
#include "bit_stream.h"
#include "macros.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
#define WRITE_BE_32(ptr, val) do { \
(ptr)[0] = (val) >> 24; \
--- a/codec/encoder/core/inc/svc_enc_macroblock.h
+++ b/codec/encoder/core/inc/svc_enc_macroblock.h
@@ -39,7 +39,7 @@
#include "wels_common_basis.h"
#include "macros.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
//struct Mb_s;
--- a/codec/encoder/core/inc/svc_enc_slice_segment.h
+++ b/codec/encoder/core/inc/svc_enc_slice_segment.h
@@ -46,7 +46,7 @@
#include "memory_align.h"
#include "codec_app_def.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
// NOTE:
--- a/codec/encoder/core/inc/svc_encode_mb.h
+++ b/codec/encoder/core/inc/svc_encode_mb.h
@@ -48,7 +48,7 @@
#include "encoder_context.h"
#include "wels_func_ptr_def.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
void WelsDctMb (int16_t* pRs, uint8_t* pEncMb, int32_t iEncStride, uint8_t* pBestPred, PDctFunc pfDctFourT4);
void WelsEncRecI16x16Y (sWelsEncCtx* pEncCtx, SMB* pCurMb, SMbCache* pMbCache);
--- a/codec/encoder/core/inc/svc_encode_slice.h
+++ b/codec/encoder/core/inc/svc_encode_slice.h
@@ -45,7 +45,7 @@
#include "svc_enc_macroblock.h"
#include "mb_cache.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
#if defined(MB_TYPES_CHECK)
void WelsCountMbType (int32_t (*iMbCount)[18], const EWelsSliceType eSt, const SMB* pMb);
#endif
--- a/codec/encoder/core/inc/svc_mode_decision.h
+++ b/codec/encoder/core/inc/svc_mode_decision.h
@@ -47,7 +47,7 @@
#include "md.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
////////////////////////
// INTERFACE, called by svc_encode_slice.c
///////////////////////
--- a/codec/encoder/core/inc/svc_motion_estimate.h
+++ b/codec/encoder/core/inc/svc_motion_estimate.h
@@ -44,7 +44,7 @@
#include "encoder_context.h"
#include "wels_func_ptr_def.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
#define CAMERA_STARTMV_RANGE (64)
#define ITERATIVE_TIMES (16)
#define CAMERA_MV_RANGE (CAMERA_STARTMV_RANGE+ITERATIVE_TIMES)
--- a/codec/encoder/core/inc/svc_set_mb_syn_cavlc.h
+++ b/codec/encoder/core/inc/svc_set_mb_syn_cavlc.h
@@ -48,7 +48,7 @@
#include "set_mb_syn_cavlc.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
int32_t WelsWriteMbResidual (SWelsFuncPtrList* pFuncList, SMbCache* sMbCacheInfo, SMB* pCurMb, SBitStringAux* pBs);
--- a/codec/encoder/core/inc/vlc_encoder.h
+++ b/codec/encoder/core/inc/vlc_encoder.h
@@ -40,7 +40,7 @@
/* VLC FOR WELS ENCODER */
/************************************************************************/
-namespace WelsSVCEnc {
+namespace WelsEnc {
//g_kuiVlcCoeffToken[uiNc][total-coeff][trailing-ones][0--value, 1--bit count]
extern const uint8_t g_kuiVlcCoeffToken[5][17][4][2];
--- a/codec/encoder/core/inc/wels_common_basis.h
+++ b/codec/encoder/core/inc/wels_common_basis.h
@@ -43,7 +43,7 @@
using namespace WelsCommon;
-namespace WelsSVCEnc {
+namespace WelsEnc {
struct SMVUnitXY { // each 4 Bytes
--- a/codec/encoder/core/inc/wels_func_ptr_def.h
+++ b/codec/encoder/core/inc/wels_func_ptr_def.h
@@ -45,7 +45,7 @@
#include "rc.h"
#include "IWelsVP.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
typedef struct TagWelsFuncPointerList SWelsFuncPtrList;
@@ -289,6 +289,6 @@
PCavlcParamCalFunc pfCavlcParamCal;
};
-} //end of namespace WelsSVCEnc {
+} //end of namespace WelsEnc {
#endif//WELS_ENCODER_FUNCTION_POINTERS_DEFINITION_H_
--- a/codec/encoder/core/inc/wels_preprocess.h
+++ b/codec/encoder/core/inc/wels_preprocess.h
@@ -50,7 +50,7 @@
#include "IWelsVP.h"
#include "param_svc.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
typedef struct TagWelsEncCtx sWelsEncCtx;
--- a/codec/encoder/core/inc/wels_transpose_matrix.h
+++ b/codec/encoder/core/inc/wels_transpose_matrix.h
@@ -34,7 +34,7 @@
#include "typedefs.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
#ifdef X86_ASM
extern "C"
--- a/codec/encoder/core/src/au_set.cpp
+++ b/codec/encoder/core/src/au_set.cpp
@@ -41,7 +41,7 @@
#include "au_set.h"
#include "svc_enc_golomb.h"
#include "macros.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
#define LEVEL_NUMBER 16
@@ -501,4 +501,4 @@
return 0;
}
-} // namespace WelsSVCEnc
+} // namespace WelsEnc
--- a/codec/encoder/core/src/deblocking.cpp
+++ b/codec/encoder/core/src/deblocking.cpp
@@ -41,7 +41,7 @@
#include "deblocking.h"
#include "cpu_core.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
#define g_kuiAlphaTable(x) g_kuiAlphaTable[(x)]
#define g_kiBetaTable(x) g_kiBetaTable[(x)]
@@ -860,5 +860,5 @@
}
-} // namespace WelsSVCEnc
+} // namespace WelsEnc
--- a/codec/encoder/core/src/decode_mb_aux.cpp
+++ b/codec/encoder/core/src/decode_mb_aux.cpp
@@ -33,7 +33,7 @@
#include "decode_mb_aux.h"
#include "cpu_core.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
/****************************************************************************
* Dequant and Ihdm functions
****************************************************************************/
--- a/codec/encoder/core/src/encode_mb_aux.cpp
+++ b/codec/encoder/core/src/encode_mb_aux.cpp
@@ -34,7 +34,7 @@
#include "ls_defines.h"
#include "encode_mb_aux.h"
#include "cpu_core.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
ALIGNED_DECLARE (const int16_t, g_kiQuantInterFF[58][8], 16) = {
/* 0*/ { 0, 1, 0, 1, 1, 1, 1, 1 },
--- a/codec/encoder/core/src/encoder.cpp
+++ b/codec/encoder/core/src/encoder.cpp
@@ -55,7 +55,7 @@
#include "slice_multi_threading.h"
// global function pointers definition
-namespace WelsSVCEnc {
+namespace WelsEnc {
/* Motion compensation */
--- a/codec/encoder/core/src/encoder_data_tables.cpp
+++ b/codec/encoder/core/src/encoder_data_tables.cpp
@@ -34,7 +34,7 @@
// export date cross various modules (.c)
#include "md.h"
#include "vlc_encoder.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// extern at mb_cache.h
--- a/codec/encoder/core/src/encoder_ext.cpp
+++ b/codec/encoder/core/src/encoder_ext.cpp
@@ -55,7 +55,7 @@
#include "slice_multi_threading.h"
#include "measure_time.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
int32_t WelsCodeOnePicPartition (sWelsEncCtx* pCtx,
@@ -3997,4 +3997,4 @@
return ENC_RETURN_SUCCESS;
}
-} // namespace WelsSVCEnc
+} // namespace WelsEnc
--- a/codec/encoder/core/src/get_intra_predictor.cpp
+++ b/codec/encoder/core/src/get_intra_predictor.cpp
@@ -43,7 +43,7 @@
#include "cpu_core.h"
#include "get_intra_predictor.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
#define I4x4_COUNT 4
#define I8x8_COUNT 8
#define I16x16_COUNT 16
--- a/codec/encoder/core/src/mc.cpp
+++ b/codec/encoder/core/src/mc.cpp
@@ -41,7 +41,7 @@
#include "mc.h"
#include "cpu_core.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
/*------------------weight for chroma fraction pixel interpolation------------------*/
//kuiA = (8 - dx) * (8 - dy);
//kuiB = dx * (8 - dy);
--- a/codec/encoder/core/src/md.cpp
+++ b/codec/encoder/core/src/md.cpp
@@ -43,7 +43,7 @@
#include "cpu_core.h"
#include "svc_enc_golomb.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
#define INTRA_VARIANCE_SAD_THRESHOLD 150
#define INTER_VARIANCE_SAD_THRESHOLD 20
--- a/codec/encoder/core/src/mv_pred.cpp
+++ b/codec/encoder/core/src/mv_pred.cpp
@@ -40,7 +40,7 @@
#include "mv_pred.h"
#include "ls_defines.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
//basic pMv prediction unit for pMv width (4, 2, 1)
void PredMv (const SMVComponentUnit* kpMvComp, int8_t iPartIdx, int8_t iPartW, int32_t iRef, SMVUnitXY* sMvp) {
const uint8_t kuiLeftIdx = g_kuiCache30ScanIdx[iPartIdx] - 1;
@@ -359,4 +359,4 @@
pMvComp->sMotionVectorCache[7 + kuiCacheIdx] = *pMv;
}
-} // namespace WelsSVCEnc
+} // namespace WelsEnc
--- a/codec/encoder/core/src/nal_encap.cpp
+++ b/codec/encoder/core/src/nal_encap.cpp
@@ -39,7 +39,7 @@
#include "nal_encap.h"
#include "svc_enc_golomb.h"
#include "ls_defines.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
/*!
* \brief load an initialize NAL pRawNal pData
*/
@@ -197,4 +197,4 @@
return 0;
}
-} // namespace WelsSVCEnc
+} // namespace WelsEnc
--- a/codec/encoder/core/src/picture_handle.cpp
+++ b/codec/encoder/core/src/picture_handle.cpp
@@ -39,7 +39,7 @@
#include "picture_handle.h"
#include "svc_motion_estimate.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
/*!
* \brief alloc picture pData with borders for each plane based width and height of picture
* \param cx width of picture in pixels
@@ -194,5 +194,5 @@
*ppPic2 = tmp;
}
-} // namespace WelsSVCEnc
+} // namespace WelsEnc
--- a/codec/encoder/core/src/property.cpp
+++ b/codec/encoder/core/src/property.cpp
@@ -39,7 +39,7 @@
*/
#include "property.h"
#include "crt_util_safe_x.h" // Safe CRT routines like utils for cross_platforms
-namespace WelsSVCEnc {
+namespace WelsEnc {
#define WELS_CODE_NAME "Wels"
#define WELS_LIB_NAME "Encoder"
@@ -136,4 +136,4 @@
return iLen;
}
-} // namespace WelsSVCEnc
+} // namespace WelsEnc
--- a/codec/encoder/core/src/ratectl.cpp
+++ b/codec/encoder/core/src/ratectl.cpp
@@ -47,7 +47,7 @@
#include "svc_enc_golomb.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
//#define _TEST_TEMP_RC_
#ifdef _TEST_TEMP_RC_
--- a/codec/encoder/core/src/ref_list_mgr_svc.cpp
+++ b/codec/encoder/core/src/ref_list_mgr_svc.cpp
@@ -34,7 +34,7 @@
#include "ref_list_mgr_svc.h"
#include "utils.h"
#include "picture_handle.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
/*
* set picture as unreferenced
*/
@@ -912,5 +912,5 @@
pFuncList->pUpdateRefList = WelsUpdateRefList;
}
}
-} // namespace WelsSVCEnc
+} // namespace WelsEnc
--- a/codec/encoder/core/src/sample.cpp
+++ b/codec/encoder/core/src/sample.cpp
@@ -44,7 +44,7 @@
#include "mc.h"
#include "cpu_core.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
int32_t WelsSampleSatd4x4_c (uint8_t* pSample1, int32_t iStride1, uint8_t* pSample2, int32_t iStride2) {
int32_t iSatdSum = 0;
int32_t pSampleMix[4][4] = {{ 0 }};
@@ -443,4 +443,4 @@
#endif
}
-} // namespace WelsSVCEnc
+} // namespace WelsEnc
--- a/codec/encoder/core/src/set_mb_syn_cavlc.cpp
+++ b/codec/encoder/core/src/set_mb_syn_cavlc.cpp
@@ -43,7 +43,7 @@
#include "cpu_core.h"
#include "wels_const.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
const ALIGNED_DECLARE (uint8_t, g_kuiZeroLeftMap[16], 16) = {
0, 1, 2, 3, 4, 5, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7
@@ -210,4 +210,4 @@
#endif
}
-} // namespace WelsSVCEnc
+} // namespace WelsEnc
--- a/codec/encoder/core/src/slice_multi_threading.cpp
+++ b/codec/encoder/core/src/slice_multi_threading.cpp
@@ -69,7 +69,7 @@
#define MT_TRACE_LOG(x, ...)
#endif
-namespace WelsSVCEnc {
+namespace WelsEnc {
void UpdateMbListNeighborParallel (SSliceCtx* pSliceCtx,
SMB* pMbList,
const int32_t uiSliceIdc) {
--- a/codec/encoder/core/src/svc_base_layer_md.cpp
+++ b/codec/encoder/core/src/svc_base_layer_md.cpp
@@ -44,7 +44,7 @@
#include "encoder.h"
#include "svc_encode_mb.h"
#include "svc_encode_slice.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
static const ALIGNED_DECLARE (int8_t, g_kiIntra16AvaliMode[8][5], 16) = {
{ I16_PRED_DC_128, I16_PRED_INVALID, I16_PRED_INVALID, I16_PRED_INVALID, 1 },
{ I16_PRED_DC_L, I16_PRED_H, I16_PRED_INVALID, I16_PRED_INVALID, 2 },
@@ -1809,4 +1809,4 @@
pCurMb->pSadCost[0] = 0;
}
-} // namespace WelsSVCEnc
+} // namespace WelsEnc
--- a/codec/encoder/core/src/svc_enc_slice_segment.cpp
+++ b/codec/encoder/core/src/svc_enc_slice_segment.cpp
@@ -40,7 +40,7 @@
#include <string.h>
#include "rc.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
/*!
* \brief Assign MB map for single slice segment
*
@@ -694,4 +694,4 @@
return ((uiMaximumNum - iConsumedNum - 1) / iDulplicateTimes);
}
-} // namespace WelsSVCEnc
+} // namespace WelsEnc
--- a/codec/encoder/core/src/svc_encode_mb.cpp
+++ b/codec/encoder/core/src/svc_encode_mb.cpp
@@ -43,7 +43,7 @@
#include "decode_mb_aux.h"
#include "ls_defines.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
void WelsDctMb (int16_t* pRes, uint8_t* pEncMb, int32_t iEncStride, uint8_t* pBestPred, PDctFunc pfDctFourT4) {
pfDctFourT4 (pRes, pEncMb, iEncStride, pBestPred, 16);
pfDctFourT4 (pRes + 64, pEncMb + 8, iEncStride, pBestPred + 8, 16);
@@ -383,4 +383,4 @@
}
}
-} // namespace WelsSVCEnc
+} // namespace WelsEnc
--- a/codec/encoder/core/src/svc_encode_slice.cpp
+++ b/codec/encoder/core/src/svc_encode_slice.cpp
@@ -47,7 +47,7 @@
#include "decode_mb_aux.h"
#include "svc_mode_decision.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
//#define ENC_TRACE
typedef int32_t (*PWelsCodingSliceFunc) (sWelsEncCtx* pCtx, SSlice* pSlice);
@@ -1146,4 +1146,4 @@
return iEncReturn;
}
-}//namespace WelsSVCEnc
+}//namespace WelsEnc
--- a/codec/encoder/core/src/svc_mode_decision.cpp
+++ b/codec/encoder/core/src/svc_mode_decision.cpp
@@ -45,7 +45,7 @@
#include "svc_base_layer_md.h"
#include "svc_mode_decision.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
//////////////
// MD for enhancement layers
@@ -662,4 +662,4 @@
void SetScrollingMvToMdNull (void* pVaa, void* pWelsMd) {
}
-} // namespace WelsSVCEnc
+} // namespace WelsEnc
--- a/codec/encoder/core/src/svc_motion_estimate.cpp
+++ b/codec/encoder/core/src/svc_motion_estimate.cpp
@@ -43,7 +43,7 @@
#include "svc_motion_estimate.h"
#include "wels_transpose_matrix.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
const int32_t QStepx16ByQp[52] = { /* save QStep<<4 for int32_t */
10, 11, 13, 14, 16, 18, /* 0~5 */
@@ -1019,5 +1019,5 @@
}
-} // namespace WelsSVCEnc
+} // namespace WelsEnc
--- a/codec/encoder/core/src/svc_set_mb_syn_cavlc.cpp
+++ b/codec/encoder/core/src/svc_set_mb_syn_cavlc.cpp
@@ -42,7 +42,7 @@
#include "ls_defines.h"
#include "svc_set_mb_syn_cavlc.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
const uint32_t g_kuiIntra4x4CbpMap[48] = {
3, 29, 30, 17, 31, 18, 37, 8, 32, 38, 19, 9, 20, 10, 11, 2, //15
16, 33, 34, 21, 35, 22, 39, 4, 36, 40, 23, 5, 24, 6, 7, 1, //31
@@ -369,4 +369,4 @@
return 0;
}
-} // namespace WelsSVCEnc
+} // namespace WelsEnc
--- a/codec/encoder/core/src/wels_preprocess.cpp
+++ b/codec/encoder/core/src/wels_preprocess.cpp
@@ -36,7 +36,7 @@
#include "utils.h"
#include "encoder.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
#define WelsSafeDelete(p) if(p){ delete (p); (p) = NULL; }
@@ -1219,4 +1219,4 @@
}
//*********************************************************************************************************/
-} // namespace WelsSVCEnc
+} // namespace WelsEnc
--- a/codec/encoder/plus/inc/welsEncoderExt.h
+++ b/codec/encoder/plus/inc/welsEncoderExt.h
@@ -55,7 +55,7 @@
//#define REC_FRAME_COUNT
class ISVCEncoder;
-namespace WelsSVCEnc {
+namespace WelsEnc {
class CWelsH264SVCEncoder : public ISVCEncoder {
public:
CWelsH264SVCEncoder();
--- a/codec/encoder/plus/src/welsEncoderExt.cpp
+++ b/codec/encoder/plus/src/welsEncoderExt.cpp
@@ -52,7 +52,7 @@
#include <sys/time.h>
#endif
-namespace WelsSVCEnc {
+namespace WelsEnc {
/*
* CWelsH264SVCEncoder class implementation
@@ -1102,7 +1102,7 @@
}
}
-using namespace WelsSVCEnc;
+using namespace WelsEnc;
int32_t WelsCreateSVCEncoder (ISVCEncoder** ppEncoder) {
if ((*ppEncoder = new CWelsH264SVCEncoder()) != NULL) {
--- a/test/encoder/EncUT_DecodeMbAux.cpp
+++ b/test/encoder/EncUT_DecodeMbAux.cpp
@@ -4,7 +4,7 @@
#include "macros.h"
#include "cpu.h"
-using namespace WelsSVCEnc;
+using namespace WelsEnc;
TEST (DecodeMbAuxTest, TestIhdm_4x4_dc) {
--- a/test/encoder/EncUT_EncoderMb.cpp
+++ b/test/encoder/EncUT_EncoderMb.cpp
@@ -3,7 +3,7 @@
#include "memory_align.h"
#include "utils/DataGenerator.h"
-using namespace WelsSVCEnc;
+using namespace WelsEnc;
#include "encode_mb_aux.h"
ALIGNED_DECLARE (const int16_t, g_kiQuantInterFFCompare[104][8], 16) = {
--- a/test/encoder/EncUT_EncoderMbAux.cpp
+++ b/test/encoder/EncUT_EncoderMbAux.cpp
@@ -3,7 +3,7 @@
#include "encode_mb_aux.h"
#include "wels_common_basis.h"
-using namespace WelsSVCEnc;
+using namespace WelsEnc;
#define ALLOC_MEMORY(type, name, num) type* name = (type*)cMemoryAlign.WelsMalloc(num*sizeof(type), #name);
#define FREE_MEMORY(name) cMemoryAlign.WelsFree(name, #name);
--- a/test/encoder/EncUT_ExpGolomb.cpp
+++ b/test/encoder/EncUT_ExpGolomb.cpp
@@ -3,7 +3,7 @@
#include "svc_enc_golomb.h"
#include "macros.h"
-using namespace WelsSVCEnc;
+using namespace WelsEnc;
const double g_kdLog2Factor = 1.0 / log (2.0);
--- a/test/encoder/EncUT_GetIntraPredictor.cpp
+++ b/test/encoder/EncUT_GetIntraPredictor.cpp
@@ -5,7 +5,8 @@
#include "ls_defines.h"
#include "macros.h"
-using namespace WelsSVCEnc;
+using namespace WelsEnc;
+
TEST (GetIntraPredictorTest, TestGetI4x4LumaPredV) {
uint8_t* pPred = new uint8_t[64];
uint8_t* pRef = new uint8_t[64];
--- a/test/encoder/EncUT_MBCopy.cpp
+++ b/test/encoder/EncUT_MBCopy.cpp
@@ -10,7 +10,7 @@
#include "wels_func_ptr_def.h"
#include "copy_mb.h"
-using namespace WelsSVCEnc;
+using namespace WelsEnc;
#define MBCOPYTEST_NUM 1000
static void FillWithRandomData (uint8_t* p, int32_t Len) {
for (int32_t i = 0; i < Len; i++) {
--- a/test/encoder/EncUT_MemoryAlloc.cpp
+++ b/test/encoder/EncUT_MemoryAlloc.cpp
@@ -1,7 +1,7 @@
#include "gtest/gtest.h"
#include "memory_align.h"
-using namespace WelsSVCEnc;
+using namespace WelsEnc;
//Tests of WelsGetCacheLineSize Begin
TEST (MemoryAlignTest, GetCacheLineSize_LoopWithin16K) {
--- a/test/encoder/EncUT_MemoryZero.cpp
+++ b/test/encoder/EncUT_MemoryZero.cpp
@@ -9,7 +9,7 @@
#include "wels_func_ptr_def.h"
#include "../../codec/encoder/core/src/encoder.cpp"
-using namespace WelsSVCEnc;
+using namespace WelsEnc;
#define MEMORYZEROTEST_NUM 1000
TEST (SetMemZeroFunTest, WelsSetMemZero) {
--- a/test/encoder/EncUT_MotionEstimate.cpp
+++ b/test/encoder/EncUT_MotionEstimate.cpp
@@ -7,7 +7,7 @@
#include "wels_func_ptr_def.h"
#include "cpu.h"
-using namespace WelsSVCEnc;
+using namespace WelsEnc;
void CopyTargetBlock (uint8_t* pSrcBlock, const int32_t kiBlockSize, SMVUnitXY sTargetMv, const int32_t kiRefPicStride,
uint8_t* pRefPic) {
--- a/test/encoder/EncUT_Reconstruct.cpp
+++ b/test/encoder/EncUT_Reconstruct.cpp
@@ -10,7 +10,7 @@
#include "decode_mb_aux.h"
#include "wels_func_ptr_def.h"
-using namespace WelsSVCEnc;
+using namespace WelsEnc;
#define RECONTEST_NUM 1000
static void FillWithRandomData (uint8_t* p, int32_t Len) {
for (int32_t i = 0; i < Len; i++) {
--- a/test/encoder/EncUT_SVC_me.cpp
+++ b/test/encoder/EncUT_SVC_me.cpp
@@ -8,7 +8,7 @@
#include "macros.h"
#include "svc_motion_estimate.h"
-using namespace WelsSVCEnc;
+using namespace WelsEnc;
#define SVC_ME_TEST_NUM 10
static void FillWithRandomData (uint8_t* p, int32_t Len) {
for (int32_t i = 0; i < Len; i++) {
--- a/test/encoder/EncUT_Sample.cpp
+++ b/test/encoder/EncUT_Sample.cpp
@@ -7,7 +7,7 @@
#include "sad_common.h"
#include "get_intra_predictor.h"
-using namespace WelsSVCEnc;
+using namespace WelsEnc;
#ifdef X86_ASM
TEST (IntraSadSatdFuncTest, WelsIntra16x16Combined3Sad_ssse3) {
const int32_t iLineSizeDec = 32;
--- a/codec/encoder/core/src/memory_align.cpp
+++ b/codec/encoder/core/src/memory_align.cpp
@@ -35,7 +35,7 @@
#include "memory_align.h"
#include "macros.h"
-namespace WelsSVCEnc {
+namespace WelsEnc {
CMemoryAlign::CMemoryAlign (const uint32_t kuiCacheLineSize)
#ifdef MEMORY_MONITOR
@@ -143,4 +143,4 @@
return m_nMemoryUsageInBytes;
}
-} // end of namespace WelsSVCEnc
+} // end of namespace WelsEnc